@@ -168,6 +168,16 @@ public:
      */
     void setStorageInfoFromSmartctl(const QString &name, const QMap<QString, QString> &mapInfo);
 
+    /**
+     * @brief mergeDisk:将磁盘相同的SerialID合并
+     */
+    virtual void mergeDisk();
+
+    /**
+     * @brief checkDiskSize:规范磁盘大小
+     */
+    virtual void checkDiskSize();
+
     // GPU设备相关 **************************************************************************************
     /**
      * @brief addGpuDevice:添加显卡
@@ -253,6 +263,13 @@ public:
      */
     bool setBluetoothInfoFromHwinfo(const QMap<QString, QString> &mapInfo);
 
+    /**
+     * @brief setBluetoothInfoFromWifiInfo:设置由WifiInfo获取的蓝牙信息
+     * @param mapInfo:由WifiInfo获取的蓝牙信息map
+     * @return 布尔值:true设置成功；false设置失败
+     */
+    bool setBluetoothInfoFromWifiInfo(const QMap<QString, QString> &mapInfo);
+
     /**
      * @brief getBluetoothDevice
      * @param unique_id
@@ -267,6 +284,12 @@ public:
      */
     void addAudioDevice(DeviceAudio *const device);
 
+    /**
+     * @brief addAudioDevice:去除列表中重复的已禁声卡
+     * @param device:
+     */
+    void deleteDisableDuplicate_AudioDevice(void);
+
     /**
      * @brief getAudioDevice 获取音频设备
      * @param path
@@ -293,6 +316,12 @@ public:
      */
     void addNetworkDevice(DeviceNetwork *const device);
 
+    /**
+     * @brief setNetworkInfoFromWifiInfo:设置网络适配器
+     * @param mapInfo:由WifiInfo获取的网卡信息map
+     */
+    bool setNetworkInfoFromWifiInfo(const QMap<QString, QString> &mapInfo);
+
     /**
      * @brief getNetworkDevice 获取网卡设备
      * @param busInfo
@@ -542,6 +571,12 @@ public:
      */
     void setCpuNum(int num);
 
+    /**
+     * @brief setCpuFrequencyIsCur:设置频率显示是当前还是最大值
+     * @param flag:频率显示是当前还是最大值
+     */
+    void setCpuFrequencyIsCur(const bool &flag);
+
 protected:
     DeviceManager();
     ~DeviceManager();
