@@ -59,7 +59,9 @@ void CmdTool::addUsbMapInfo(const QString &key, const QMap<QString, QString> &ma
     }
 
     // 这个是用来过滤，没有接入任何设备的usb接口
-    if (mapInfo["Model"].contains("Linux Foundation") || mapInfo["Model"].contains("Wireless Network Adapter"))
+    if (mapInfo["Model"].contains("Linux Foundation")
+            || mapInfo["Model"].contains("Wireless Network Adapter")
+            || mapInfo["Model"].contains("Hub Controller"))
         return;
 
     if (mapInfo["Hardware Class"].contains("hub", Qt::CaseInsensitive))
@@ -183,8 +185,7 @@ void CmdTool::loadLshwInfo(const QString &debugFile)
             addMapInfo("lshw_multimedia", mapInfo);
         } else if (item.startsWith("network")) {      // 网卡信息
             getMapInfoFromLshw(item, mapInfo);
-            if (!item.contains(QRegExp(".*network:[0-9] DISABLED.*")))
-                addMapInfo("lshw_network", mapInfo);
+            addMapInfo("lshw_network", mapInfo);
         } else if (item.startsWith("usb")) {          // USB 设备信息
             getMapInfoFromLshw(item, mapInfo);
             addMapInfo("lshw_usb", mapInfo);
@@ -349,7 +350,7 @@ void CmdTool::loadBluetoothCtlInfo(QMap<QString, QString> &mapInfo)
     QString deviceInfo;
 
     // 读取文件信息
-    if (!getDeviceInfo(deviceInfo, "bluetoothctl.txt")) {
+    if (!getDeviceInfoFromCmd(deviceInfo, "bluetoothctl show " + mapInfo["BD Address"])) {
         addMapInfo("hciconfig", mapInfo);
         return;
     }
@@ -422,7 +423,8 @@ void CmdTool::getMulHwinfoInfo(const QString &info)
             continue;
         QMap<QString, QString> mapInfo;
         getMapInfoFromHwinfo(item, mapInfo);
-        if (mapInfo["Hardware Class"] == "sound") {
+        if (mapInfo["Hardware Class"] == "sound" || mapInfo["Device"].contains("USB Audio")) {
+            // mapInfo["Device"].contains("USB Audio") 是为了处理未识别的USB声卡 Bug-118773
             addMapInfo("hwinfo_sound", mapInfo);
         } else if (mapInfo["Hardware Class"].contains("network")) {
             //if (mapInfo.find("SysFS Device Link") != mapInfo.end() && mapInfo["SysFS Device Link"].contains("/devices/platform"))
@@ -442,6 +444,7 @@ void CmdTool::getMulHwinfoInfo(const QString &info)
         } else if ("graphics card" == mapInfo["Hardware Class"]) {
             if (mapInfo["Device"].contains("Graphics Processing Unit"))
                 continue;
+            addWidthToMap(mapInfo);
             addMapInfo("hwinfo_display", mapInfo);
         } else {
             addUsbMapInfo("hwinfo_usb", mapInfo);
@@ -449,6 +452,28 @@ void CmdTool::getMulHwinfoInfo(const QString &info)
     }
 }
 
+void CmdTool::addWidthToMap(QMap<QString, QString> &mapInfo)
+{
+    QString vendor = mapInfo["Vendor"];
+    if(!vendor.contains("NVIDIA Corporation")){
+        return;
+    }
+
+    QString cmd = QString("nvidia-settings -q GPUMemoryInterface");
+    QString sInfo;
+    QProcess process;
+    process.start(cmd);
+    process.waitForFinished(-1);
+    sInfo = process.readAllStandardOutput();
+    QStringList lines = sInfo.split("\n");
+    foreach (const QString &line, lines) {
+        QRegExp reg("\\s\\sAttribute\\s'GPUMemoryInterface' \\(.*\\):\\s([0-9]{2}).*");
+        if(reg.exactMatch(line)){
+            mapInfo.insert("Width",reg.cap(1) + " bits");
+        }
+    }
+}
+
 void CmdTool::loadDmidecodeInfo(const QString &key, const QString &debugfile)
 {
     // dmidecode -t 2信息单独处理
@@ -698,6 +723,7 @@ void CmdTool::getSMBIOSVersion(const QString &info, QString &version)
 
 void CmdTool::loadNvidiaSettingInfo(const QString &key, const QString &debugfile)
 {
+    Q_UNUSED(debugfile);
     // 加载nvidia-settings  -q  VideoRam 信息
     // 命令与xrandr命令一样无法在后台运行,该从前台命令直接获取信息
     QString deviceInfo;
@@ -861,6 +887,10 @@ void CmdTool::getMapInfoFromHwinfo(const QString &info, QMap<QString, QString> &
     QStringList infoList = info.split("\n");
     for (QStringList::iterator it = infoList.begin(); it != infoList.end(); ++it) {
         QStringList words = (*it).split(ch);
+        if((*it).contains("PS/2 Mouse")){
+            words.clear();
+            words << "Hotplug" << "PS/2";
+        }
         if (words.size() != 2)
             continue;
 
@@ -873,7 +903,8 @@ void CmdTool::getMapInfoFromHwinfo(const QString &info, QMap<QString, QString> &
             QString value = re.cap(1);
 
             //这里是为了防止  "usb-storage", "sr"  -》 usb-storage", "sr
-            if ("Driver" == key)
+            // bug112311 驱动模块显示异常
+            if ("Driver" ==  key || "Driver Modules" ==  key)
                 value.replace("\"", "");
 
             // 如果信息中有unknown 则过滤
@@ -1099,7 +1130,11 @@ void CmdTool::getMapInfoFromBluetoothCtl(QMap<QString, QString> &mapInfo, const
         QStringList keyValue = line.trimmed().split(": ");
         if (2 == keyValue.size()) {
             if ("UUID" == keyValue[0]) {
-                uuid.append(keyValue[1]);
+                QString valueStr = keyValue[1].trimmed();
+                QStringList valueStrList = valueStr.split("(",QString::SkipEmptyParts);
+                if(valueStrList.size() == 2)
+                    valueStr = valueStrList[0].trimmed() + ":(" + valueStrList[1];
+                uuid.append(valueStr);
                 uuid.append("\n");
             } else {
                 mapInfo[keyValue[0].trimmed()] = keyValue[1].trimmed();
