@@ -6,15 +6,14 @@
 #include "KLUGenerator.h"
 #include "PanguGenerator.h"
 #include "PanguVGenerator.h"
-#include "commondefine.h"
+#include "HWGenerator.h"
+#include "KLVGenerator.h"
+#include "commonfunction.h"
 
 // Qt库文件
 #include <QProcess>
 #include <QFile>
 
-// 其它头文件
-#include <sys/utsname.h>
-
 DeviceFactory::DeviceFactory()
 {
 
@@ -23,11 +22,7 @@ DeviceFactory::DeviceFactory()
 DeviceGenerator *DeviceFactory::getDeviceGenerator()
 {
     // 获取系统架构
-    QString arch;
-    struct utsname utsbuf;
-    if (-1 == uname(&utsbuf)){
-        arch = QString::fromLocal8Bit(utsbuf.machine);
-    }
+    QString arch = Common::getArch();
 
     // 根据架构创建设备信息生成器
     DeviceGenerator *generator = nullptr;
@@ -35,9 +30,18 @@ DeviceGenerator *DeviceFactory::getDeviceGenerator()
         generator = new X86Generator();
     else if (arch == "mips64")
         generator = new MipsGenerator();
-    else if (arch == "aarch64")
-        generator = new ArmGenerator();
-    else
+    else if (arch == "aarch64") {
+        QString type = Common::boardVendorType();
+        if (!type.isEmpty()) {
+            if (type == "KLVV")
+                generator = new KLVGenerator();
+            else if (type == "PGUV")
+                generator = new PanguVGenerator();
+            else
+                generator = new HWGenerator();
+        } else
+            generator = new ArmGenerator();
+    } else
         generator = new X86Generator();
 
     return generator;
