@@ -82,11 +82,71 @@ void DeviceGenerator::generatorComputerDevice()
     DeviceManager::instance()->addComputerDevice(device);
 }
 
+void mergeSortCpuInfoByLogicalID(QList<QMap<QString, QString> > &lsCpu, QList<QMap<QString, QString> > &tmpLst, int begin, int end)
+{
+    // 合并列表
+    int left_length = (end - begin + 1) / 2;
+    int left_index = begin;
+    int right_index = begin + left_length;
+    int result_index = begin;
+
+    // 合并左右区间 左区间未合并结束且右区间未合并结束时
+    while (left_index < begin + left_length && right_index < end + 1) {
+        // 左右区间,哪个小先排哪个,下标加1
+        if (lsCpu[left_index]["processor"].toInt() <= lsCpu[right_index]["processor"].toInt())
+            tmpLst[result_index++] = lsCpu[left_index++];
+        else
+            tmpLst[result_index++] = lsCpu[right_index++];
+    }
+
+    // 合并左区间剩余数据
+    while (left_index < begin + left_length)
+        tmpLst[result_index++] = lsCpu[left_index++];
+
+    // 合并右区间剩余数据
+    while (right_index < end + 1)
+        tmpLst[result_index++] = lsCpu[right_index++];
+}
+
+void sortCpuInfoByLogicalID(QList<QMap<QString, QString> > &lsCpu, QList<QMap<QString, QString> > &tmpLst, int begin, int end)
+{
+    // 列表个数为1,直接返回
+    if (0 == end - begin)
+        return;
+
+    // bug 后台获取CPU信息是按照物理CPU,核心,逻辑CPU顺序获取的
+    // 界面上展示顺序混乱实际是按照物理CPU,核心,逻辑CPU顺序展示
+    // 与产品沟通后,按照用户的使用感修改,CPU信息按照逻辑CPU的id从小到大显示
+    // 区间个数为2
+    if (1 == end - begin) {
+        // 前 processor > 后 processor 时交换位置
+        if (lsCpu[begin]["processor"].toInt() > lsCpu[end]["processor"].toInt()) {
+            QMap<QString, QString> tmpMap = lsCpu[begin];
+            lsCpu[begin] = lsCpu[end];
+            lsCpu[end] = tmpMap;
+        }
+    } else {
+        // 区间个数 > 2 递归
+        sortCpuInfoByLogicalID(lsCpu, tmpLst, begin, (end - begin) / 2 + begin);
+        sortCpuInfoByLogicalID(lsCpu, tmpLst, (end - begin + 1) / 2 + begin, end);
+        mergeSortCpuInfoByLogicalID(lsCpu, tmpLst, begin, end);
+        lsCpu = tmpLst;
+    }
+}
+
 void DeviceGenerator::generatorCpuDevice()
 {
     // 生成CPU
     // get info from lscpu
     const QList<QMap<QString, QString> >  &lsCpu = DeviceManager::instance()->cmdInfo("lscpu");
+    QList<QMap<QString, QString> > tmpLst;
+    QList<QMap<QString, QString> > srcLst;
+    tmpLst.append(lsCpu);
+    srcLst.append(lsCpu);
+
+    // 按照processor id 从小到大排序
+    if (lsCpu.size() > 1)
+        sortCpuInfoByLogicalID(srcLst, tmpLst, 0, lsCpu.size() - 1);
 
     // get info from lshw
     const QList<QMap<QString, QString> >  &lshwCpu = DeviceManager::instance()->cmdInfo("lshw_cpu");
@@ -109,11 +169,16 @@ void DeviceGenerator::generatorCpuDevice()
         logicalNum = map["logical"].toInt();
 
     // set cpu number
-    DeviceManager::instance()->setCpuNum(dmidecode4.size());
+    QSet<QString> allCPUS;
+    for (auto dd4:dmidecode4) {
+        if(dd4.contains("Socket Designation"))
+            allCPUS.insert(dd4["Socket Designation"]);
+    }
+    DeviceManager::instance()->setCpuNum(allCPUS.isEmpty() ? dmidecode4.size() : allCPUS.size());
 
     // set cpu info
-    QList<QMap<QString, QString> >::const_iterator it = lsCpu.begin();
-    for (; it != lsCpu.end(); ++it) {
+    QList<QMap<QString, QString> >::const_iterator it = srcLst.begin();
+    for (; it != srcLst.end(); ++it) {
         DeviceCpu *device = new DeviceCpu;
         device->setCpuInfo(*it, lshw, dmidecode, coreNum, logicalNum);
         DeviceManager::instance()->addCpuDevice(device);
@@ -147,6 +212,7 @@ void DeviceGenerator::generatorDiskDevice()
 
     getDiskInfoFromLsblk();
     getDiskInfoFromSmartCtl();
+    DeviceManager::instance()->mergeDisk();
 }
 
 void DeviceGenerator::generatorGpuDevice()
@@ -165,112 +231,55 @@ void DeviceGenerator::generatorMonitorDevice()
 
 void DeviceGenerator::generatorNetworkDevice()
 {
-    const QList<QMap<QString, QString>> &lstHWInfo = DeviceManager::instance()->cmdInfo("hwinfo_network");
     QList<DeviceNetwork *> lstDevice;
+    const QList<QMap<QString, QString>> &lstHWInfo = DeviceManager::instance()->cmdInfo("hwinfo_network");
     for (QList<QMap<QString, QString> >::const_iterator it = lstHWInfo.begin(); it != lstHWInfo.end(); ++it) {
         // Hardware Class 类型为 network interface
         if ("network" == (*it)["Hardware Class"]) {
             continue;
         }
 
-        // 判断该网卡是否存在，被禁用的移动网卡被拔出
-        QString path = pciPath(*it);
-        if (path.contains("usb")) {
-            if (!QFile::exists(path)) {
-                continue;
+        // 先判断是否是有效网卡信息
+        // 符合两种情况中的一种 1. "HW Address" 和 "Permanent HW Address" 都必须有  2. 有 "unique_id"
+        if (((*it).find("HW Address") == (*it).end() || (*it).find("Permanent HW Address") == (*it).end()) && ((*it).find("unique_id") == (*it).end())) {
+            continue;
+        }
+
+        // 如果(*it)中包含unique_id属性，则说明是从数据库里面获取的，否则是从hwinfo中获取的
+        if ((*it).find("unique_id") == (*it).end()) {
+            DeviceNetwork *device = new DeviceNetwork();
+            device->setInfoFromHwinfo(*it);
+            lstDevice.append(device);
+        } else {
+            DeviceNetwork *device = nullptr;
+            const QString &unique_id = (*it)["unique_id"];
+            for (QList<DeviceNetwork *>::iterator itNet = lstDevice.begin(); itNet != lstDevice.end(); ++itNet) {
+                if (!unique_id.isEmpty() && (*itNet)->uniqueID() == unique_id) {
+                    device = (*itNet);
+                }
+            }
+            if (device) {
+                device->setEnableValue(false);
             }
         }
-        // 没有网卡物理地址且在数据库里面找不到的的设备过滤
-        if ((*it).size() < 2)
-            continue;
+    }
 
-        // 判断重复设备数据
-        QString unique_id = uniqueID(*it);
-        DeviceNetwork *device = nullptr;
-        for (QList<DeviceNetwork*>::iterator itNet = lstDevice.begin(); itNet != lstDevice.end(); ++itNet) {
-            if(!unique_id.isEmpty() && (*itNet)->uniqueID() == unique_id){
-                device = *itNet;
+    // 设置从lshw中获取的信息
+    const QList<QMap<QString, QString>> &lstLshw = DeviceManager::instance()->cmdInfo("lshw_network");
+    for (QList<QMap<QString, QString> >::const_iterator it = lstLshw.begin(); it != lstLshw.end(); ++it) {
+        if ((*it).find("serial") == (*it).end())
+            continue;
+        const QString &serialNumber = (*it)["serial"];
+        for (QList<DeviceNetwork *>::iterator itDevice = lstDevice.begin(); itDevice != lstDevice.end(); ++itDevice) {
+            if (!serialNumber.isEmpty() && (*itDevice)->uniqueID() == serialNumber) {
+                (*itDevice)->setInfoFromLshw(*it);
                 break;
             }
         }
-        if (device) {
-            device->setEnableValue(false);
-            device->setInfoFromHwinfo(*it);
-            continue;
-        }
-
-        if ((*it).find("Permanent HW Address") != (*it).end() && (*it).find("HW Address") != (*it).end()) {
-            device = new DeviceNetwork();
-            device->setInfoFromHwinfo(*it);
-            lstDevice.append(device);
-        }
-        if ((*it).find("path") != (*it).end()) {
-            device = new DeviceNetwork();
-            device->setInfoFromHwinfo(*it);
-            DeviceManager::instance()->addNetworkDevice(device);
-        }
     }
 
-    // 添加从lshw中获取的信息
-    const QList<QMap<QString, QString>> &lstInfo = DeviceManager::instance()->cmdInfo("lshw_network");
-    /*
-     * 存在一个网卡对应2个接口的情况，lwhw会分别读到网卡和接口的信息。
-    *-network
-       description: Network controller
-       bus info: pci@0001:01:00.0
-    *-network:0
-       serial: 30:aa:e4:a4:67:56
-    *-network:1 DISABLED
-       serial: 32:aa:e4:a4:67:56
-    */
-    QMap<QString, QString> itemWirelssNC;
-    itemWirelssNC.clear();
-    QList<QMap<QString, QString> >::const_iterator itls = lstInfo.begin();
-    for (; itls != lstInfo.end(); ++itls) {
-        if ((*itls).size() < 2)
-            continue;
-
-        if ((*itls).find("serial") != (*itls).end()) { //有mac地址，是网卡
-            QString unique_id = (*itls)["serial"];
-            DeviceNetwork *devTemp = nullptr;
-            for (QList<DeviceNetwork *>::iterator it = lstDevice.begin(); it != lstDevice.end(); ++it) {
-                DeviceNetwork *net = dynamic_cast<DeviceNetwork *>(*it);
-                if (!unique_id.isEmpty() && net && net->uniqueID() == unique_id) {
-                    devTemp = *it;
-                    break;
-                }
-            }
-            if (!devTemp) {
-                continue;
-            }
-            if ((*itls).find("bus info") != (*itls).end()) {
-                devTemp->setInfoFromLshw(*itls);
-                itemWirelssNC.clear();//清除可能的缓存
-            } else {
-                QMap<QString, QString> temp;//因为可能对应2张网卡，所以用动态局部变量
-                foreach (const QString &key, itemWirelssNC.keys()) {
-                    temp.insert(key, itemWirelssNC[key]);
-                }
-                foreach (const QString &key, (*itls).keys()) {
-                    temp.insert(key, (*itls)[key]);
-                }
-                devTemp->setInfoFromLshw(temp);
-            }
-            DeviceManager::instance()->addNetworkDevice(devTemp);
-            continue;
-        } else if ((*itls).find("bus info") != (*itls).end())  { //有总线，说明是网卡
-            foreach (const QString &key, (*itls).keys()) {
-                itemWirelssNC.insert(key, (*itls)[key]);
-            }
-            continue;
-        }
-    }
-
-    for (QList<DeviceNetwork *>::iterator it = lstDevice.begin(); it != lstDevice.end(); ++it) {
-        DeviceNetwork *net = dynamic_cast<DeviceNetwork *>(*it);
-        if (!DeviceManager::instance()->getNetworkDevice(net->uniqueID())) {
-            delete net;
-        }
+    foreach (DeviceNetwork *device, lstDevice) {
+        DeviceManager::instance()->addNetworkDevice(device);
     }
 }
 
@@ -664,6 +673,7 @@ void DeviceGenerator::getAudioInfoFromHwinfo()
         DeviceManager::instance()->addAudioDevice(device);
         addBusIDFromHwinfo((*it)["SysFS BusID"]);
     }
+    DeviceManager::instance()->deleteDisableDuplicate_AudioDevice();
 }
 
 void DeviceGenerator::getAudioInfoFromLshw()
@@ -732,7 +742,7 @@ void DeviceGenerator::getBlueToothInfoFromHwinfo()
         if ((*it)["Hardware Class"] == "hub" || (*it)["Hardware Class"] == "mouse" || (*it)["Hardware Class"] == "keyboard")
             continue;
 
-        if ((*it)["Hardware Class"] == "bluetooth" || (*it)["Driver"] == "btusb" || (*it)["Device"] == "BCM20702A0") {
+        if ((*it)["Model"].contains("bluetooth", Qt::CaseInsensitive) || (*it)["Hardware Class"] == "bluetooth" || (*it)["Driver"] == "btusb" || (*it)["Device"] == "BCM20702A0") {
 
             // 判断重复设备数据
             QString unique_id = uniqueID(*it);
@@ -814,10 +824,11 @@ void DeviceGenerator::getMouseInfoFromHwinfo()
             continue;
 
         //过滤触摸板，如果不是触摸板再检查
-        if ((*it)["Device"].indexOf("Touchpad") < 0){
+        if ((*it)["Hotplug"] != "PS/2") {
             // 先判断是否存在
             QString path = pciPath(*it);
-            if (!QFile::exists(path)) {
+            // 判断authorized是否存在，不存在则直接返回
+            if (!QFile::exists("/sys" + path + "/authorized")) {
                 continue;
             }
         }
@@ -827,8 +838,8 @@ void DeviceGenerator::getMouseInfoFromHwinfo()
         if (device) {
             device->setEnableValue(false);
             continue;
-        }else{
-            if((*it).find("path") != (*it).end()){
+        } else {
+            if ((*it).find("path") != (*it).end()) {
                 continue;
             }
         }
@@ -836,8 +847,13 @@ void DeviceGenerator::getMouseInfoFromHwinfo()
         device = new DeviceInput();
         device->setInfoFromHwinfo(*it);
         device->setHardwareClass("mouse");
-        DeviceManager::instance()->addMouseDevice(device);
-        addBusIDFromHwinfo((*it)["SysFS BusID"]);
+        if (device->bluetoothIsConnected()) {
+            DeviceManager::instance()->addMouseDevice(device);
+            addBusIDFromHwinfo((*it)["SysFS BusID"]);
+        } else {
+            delete device;
+            device = nullptr;
+        }
     }
 
     //  加载从hwinfo --usb中获取的触摸屏信息具有鼠标功能，放到鼠标设备中
@@ -896,7 +912,8 @@ void DeviceGenerator::getImageInfoFromHwinfo()
         // 判断该摄像头是否存在，被禁用的和被拔出
         QString path = pciPath(*it);
         if (path.contains("usb")) {
-            if (!QFile::exists(path)) {
+            // 判断authorized是否存在，不存在则直接返回
+            if (!QFile::exists("/sys" + path + "/authorized")) {
                 continue;
             }
         }
@@ -908,11 +925,11 @@ void DeviceGenerator::getImageInfoFromHwinfo()
             device->setEnableValue(false);
             device->setInfoFromHwinfo(*it);
             continue;
-        }else{
-            if((*it).find("path") != (*it).end()){
+        } else {
+            if ((*it).find("path") != (*it).end()) {
                 continue;
             }
-       }
+        }
 
         device = new DeviceImage();
         device->setInfoFromHwinfo(*it);
@@ -971,6 +988,17 @@ void DeviceGenerator::getOthersInfoFromHwinfo()
     for (; it != lstMap.end(); ++it) {
         if ((*it).size() < 3)
             continue;
+/*  bug 141439 不可见功能设计需要再次思考*/
+        if (  (*it).find("Device") != (*it).end() &&
+             ((*it)["Device"].contains("fingerprint", Qt::CaseInsensitive)  ||  
+              (*it)["Device"].contains("MOH", Qt::CaseInsensitive)
+             )) { 
+            DeviceOthers *device = new DeviceOthers();
+            device->setForcedDisplay(true);
+            device->setInfoFromHwinfo(*it);
+            DeviceManager::instance()->addOthersDevice(device);
+            continue;
+        }
 
         bool isOtherDevice = true;
         QString curBus = (*it)["SysFS BusID"];
@@ -979,7 +1007,7 @@ void DeviceGenerator::getOthersInfoFromHwinfo()
         // 判断该设备是否已经在其他类别中显示
         if ((*it).find("unique_id") != (*it).end() && (*it)["Hardware Class"] != "others") {
             isOtherDevice = false;
-        } else if((*it).find("unique_id") == (*it).end()){
+        } else if ((*it).find("unique_id") == (*it).end()) {
             if (curBus.isEmpty() || lstBusId.indexOf(curBus) != -1)
                 isOtherDevice = false;
         }
@@ -988,7 +1016,8 @@ void DeviceGenerator::getOthersInfoFromHwinfo()
         if (isOtherDevice) {
             // 先判断是否存在
             QString path = pciPath(*it);
-            if (!QFile::exists(path)) {
+            // 判断authorized是否存在，不存在则直接返回
+            if (!QFile::exists("/sys" + path + "/authorized")) {
                 continue;
             }
 
@@ -997,8 +1026,8 @@ void DeviceGenerator::getOthersInfoFromHwinfo()
             if (device) {
                 device->setEnableValue(false);
                 continue;
-            }else{
-                if((*it).find("path") != (*it).end()){
+            } else {
+                if ((*it).find("path") != (*it).end()) {
                     continue;
                 }
             }
@@ -1066,15 +1095,11 @@ const QString DeviceGenerator::getProductName()
 QString DeviceGenerator::pciPath(const QMap<QString, QString> &mapInfo)
 {
     if (mapInfo.find("path") != mapInfo.end()) { // SysFS Device Link
-        if (mapInfo["path"].contains("usb")) {
-            return "/sys" + mapInfo["path"] + "/authorized";
-        } else {
-            return mapInfo["path"];
-        }
+        return mapInfo["path"];
     } else if (mapInfo.find("SysFS Device Link") != mapInfo.end()) {
-        return "/sys" + mapInfo["SysFS Device Link"] + "/authorized";
+        return mapInfo["SysFS Device Link"];
     } else if (mapInfo.find("SysFS ID") != mapInfo.end()) {
-        return "/sys" + mapInfo["SysFS ID"] + "/authorized";
+        return mapInfo["SysFS ID"];
     } else {
         if (mapInfo["Device Files"].contains("platform")) {
             return "platform";
